@@ -55,7 +55,7 @@ def check_environment(
     verbose: Annotated[
         bool, typer.Option("--verbose", help="Print verbose output.")
     ] = False,
-):
+) -> str | None:
     """Check that an environment is up-to-date."""
     dotenv.load_dotenv(dotenv_path=".env", verbose=verbose)
     ck_info = calkit.load_calkit_info(process_includes="environments")
@@ -79,6 +79,11 @@ def check_environment(
             ),
             platform=env.get("platform"),
             deps=env.get("deps", []),
+            env_vars=env.get("env_vars", []),
+            ports=env.get("ports", []),
+            gpus=env.get("gpus"),
+            user=env.get("user"),
+            wdir=env.get("wdir"),
             quiet=not verbose,
         )
     elif env["kind"] == "conda":
@@ -136,6 +141,7 @@ def check_environment(
         )
     else:
         raise_error(f"Environment kind '{env['kind']}' not supported")
+    return get_env_lock_fpath(env=env, env_name=env_name, as_posix=False)
 
 
 @check_app.command(name="docker-env")
@@ -163,6 +169,14 @@ def check_docker_env(
         str | None,
         typer.Option("--platform", help="Which platform(s) to build for."),
     ] = None,
+    user: Annotated[
+        str | None,
+        typer.Option("--user", help="Which user to run the container as."),
+    ] = None,
+    wdir: Annotated[
+        str | None,
+        typer.Option("--wdir", help="Working directory inside the container."),
+    ] = None,
     deps: Annotated[
         list[str],
         typer.Option(
@@ -171,6 +185,30 @@ def check_docker_env(
             help="Declare an explicit dependency for this Docker image.",
         ),
     ] = [],
+    env_vars: Annotated[
+        list[str],
+        typer.Option(
+            "--env-var",
+            "-e",
+            help="Declare an explicit environment variable for the container.",
+        ),
+    ] = [],
+    ports: Annotated[
+        list[str],
+        typer.Option(
+            "--port",
+            "-p",
+            help="Declare an explicit port for the container.",
+        ),
+    ] = [],
+    gpus: Annotated[
+        str | None,
+        typer.Option(
+            "--gpus",
+            "-g",
+            help="Declare an explicit GPU requirement for the container.",
+        ),
+    ] = None,
     quiet: Annotated[
         bool, typer.Option("--quiet", "-q", help="Be quiet.")
     ] = False,
@@ -192,6 +230,7 @@ def check_docker_env(
         # content in the image
         keys = [
             "RepoTags",
+            "RepoDigests",
             "Architecture",
             "Os",
             "Size",
@@ -275,6 +314,18 @@ def check_docker_env(
     inspect = get_docker_inspect()
     inspect["DockerfileMD5"] = dockerfile_md5
     inspect["DepsMD5s"] = deps_md5s
+    if platform is not None:
+        inspect["Platform"] = platform
+    if wdir is not None:
+        inspect["WorkDir"] = wdir
+    if user is not None:
+        inspect["User"] = user
+    if env_vars:
+        inspect["EnvVars"] = env_vars
+    if ports:
+        inspect["Ports"] = ports
+    if gpus:
+        inspect["GPUs"] = gpus
     lock_dir = os.path.dirname(lock_fpath)
     if lock_dir:
         os.makedirs(lock_dir, exist_ok=True)
